NodeRef

Struct NodeRef 

pub struct NodeRef(/* private fields */);
A reference to a Node in the DOM.

Implementations

Source

impl NodeRef

pub fn new() -> Self

Creates an empty NodeRef.

pub fn get(&self) -> Node

Gets the Node stored inside the NodeRef.

Panics

Panics if the NodeRef is not set yet.

For a non panicking version, see NodeRef::try_get.

pub fn try_get(&self) -> Option<Node>

Tries to get the Node stored inside the NodeRef or None if it is not yet set.

For a panicking version, see NodeRef::get.

pub fn set(&self, node: Node)

Sets the NodeRef with the specified Node.