pub struct Owner { /* private fields */ }Expand description
Owns the effects created in the current reactive scope.
The effects are dropped and the cleanup callbacks are called when the Owner is dropped.
Implementations